pub trait KeyCombo {
// Required method
fn into_vec(self) -> Vec<Key>;
}Expand description
Trait used for various methods that can take multiple Keys.
A Key can be either Qwerty or MouseButton.
Supports being a lone key, a Vec, an array or a tuple.