Module mcp

Module mcp 

MCP server frontend for agents that need to inspect and operate a Basalt database.

The wire protocol is provided by the official rmcp implementation. This module only owns the database-facing tools, bounded result conversion, and the small basalt mcp command-line parser.

Structs

McpCliError
McpOptions
Parsed options for the basalt mcp subcommand.

Constants

HELP

Functions

parse_args
Parse arguments after the mcp subcommand.
run
Start the stdio MCP server for a direct database in read-only mode.
run_database
run_workspace