MCP server frontend for agents that need to inspect and operate a Basalt database.
The wire protocol is provided by the official rmcp implementation. This
module only owns the database-facing tools, bounded result conversion, and
the small basalt mcp command-line parser.
Structs
- McpCli
Error - McpOptions
- Parsed options for the
basalt mcpsubcommand.
Constants
Functions
- parse_
args - Parse arguments after the
mcpsubcommand. - run
- Start the stdio MCP server for a direct database in read-only mode.
- run_
database - run_
workspace